@echo off & setlocal ENABLEEXTENSIONS
rem  ---------------------------------------------------------------------
rem  GIPPtools - A collection of programs for (seismic) data pre-processing.
rem
rem  Copyright (C) 2009-2021 Christof Lendl (GFZ Potsdam, lendl@gfz-potsdam.de)
rem
rem  Licensed under the Apache License, Version 2.0 (the "License");
rem  you may not use this file except in compliance with the License.
rem  You may obtain a copy of the License at
rem
rem    http://www.apache.org/licenses/LICENSE-2.0
rem
rem  Unless required by applicable law or agreed to in writing, software
rem  distributed under the License is distributed on an "AS IS" BASIS,
rem  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
rem  See the License for the specific language governing permissions and
rem  limitations under the License.
rem  ---------------------------------------------------------------------

rem  ---------------------------------------------------------------------
rem  This (Microsoft Windows) command script functions as a "wrapper" around
rem  the various Java command line utilities that are part of the GIPPtools /
rem  CubeTools software collection.
rem
rem  To make the most efficient use of this script, simply create multiple
rem  copies of this command script, where the name of each newly created
rem  copy should be the name of one Java class or utility you intent to call.
rem  When executed from the command line, the script will look at its
rem  respective "name" and start the corresponding GIPPtools utility from
rem  the JAR file.
rem
rem  Important!  This command script makes some basic assumption about the
rem              layout of the GIPPtools subdirectories:
rem
rem    %GIPPTOOLS_HOME%
rem       \--> bin     .. contains the executable GIPPtools utilities (and
rem       \               is therefore the location of this start script)
rem       \--> java    .. JAR file(s) with the actual Java classes
rem       \--> doc     .. documentation
rem       \
rem       \--> jre     .. an optional (!!!) Java Runtime Environment (JRE) 
rem                       that can be used to build a self-contained GIPPtool
rem                       installation on e.g. a memory stick when traveling
rem                       (see "find the Java runtime" below for more details) 
rem
rem  Please also note that this script uses features and syntax that were
rem  first introduced with Windows NT. (This is also the reason why it has
rem  the file extension '.cmd' and not the more common '.bat'.)
rem
rem           It will NOT work with Windows 95, 98 or ME !
rem
rem  However, since the GIPPtools utilities require Java 8 or newer, which
rem  was never available for those platforms, this should be no problem.
rem  ---------------------------------------------------------------------


rem  --- debugging ---
rem  Report on all GIPPtools relevant environment variables that influence
rem  the behavior of this start script.

if /i "%~1"=="--debug"  (
    echo.  DEBUG: Begin GIPPtools start script.
    echo.  DEBUG:
    echo.  DEBUG:   environment  GIPPTOOLS_JAVA=%GIPPTOOLS_JAVA%
    echo.  DEBUG:   environment  GIPPTOOLS_OPTS=%GIPPTOOLS_OPTS%
    echo.  DEBUG:   environment  GIPPTOOLS_HOME=%GIPPTOOLS_HOME%
    echo.  DEBUG:
)


rem  --- name of the GIPPtools utility ---
rem  Obtain the "pure" (file-) name of this script without extension. The
rem  script name is used below as command line argument to the '--run-tool=..'
rem  command line option that determines which GIPPtools utility will be
rem  started from the JAR file.

set ToolName="%~n0"


rem  --- find the GIPPtools jar-file ---
rem  The location of the GIPPtools installation is either given via the
rem  environment variable  %GIPPTOOLS_HOME%  or determined relative to the 
rem  location of this command script. (See top of file for assumptions made
rem  about the GIPPtools directory layout.)

if defined  GIPPTOOLS_HOME  (

    set JarFile="%GIPPTOOLS_HOME:"=%\java\tools.jar"

) else (

    set JarFile="%~dp0..\java\tools.jar"
)


if not exist  %JarFile%  (
    echo.
    echo.ERROR!  Can not find the GIPPtools jar-file!
    echo.
    echo.  To run the GIPPtools Java utilities, a jar-file
    echo.  containing the Java code is required. This file
    echo.  was expected at the location:
    echo.
    echo.    %JarFile%
    echo.
    exit /B 2
)


rem  --- find the Java runtime environment ---
rem  If the variable  %GIPPTOOLS_JAVA%  is defined use the Java Runtime
rem  Environment (JRE) located there. Otherwise, search the file system for 
rem  an executable JRE (usually a file called 'java.exe').
rem
rem  Feel free to modify this to your needs although usually there is no 
rem  need to change anything

if defined  GIPPTOOLS_JAVA  (

    set JavaBin="%GIPPTOOLS_JAVA:"=%\bin\java.exe"

) else (

    rem  Check if the GIPPtools installation directory comes with it's own
    rem  Java runtime. Use this hook/hack to build self contained GIPPtools 
    rem  installations (e.g. on an USB memory stick when traveling) that will 
    rem  also work on machines without locally installed Java.
    rem
    rem  Note: The 'jre' directory inside %GIPPTOOLS_HOME% is optional! It 
    rem        is your responsibility to create the directory and to copy an 
    rem        appropriate JRE for your target system into it if you plan to 
    rem        use this "hook".
    
    if exist  "%~dp0..\jre\bin\java.exe"  (
        
        set JavaBin="%~dp0..\jre\bin\java.exe"
    )

    rem  Finally, if no JRE was found yet, try to locate Java in the normal 
    rem  Windows search path. This will be successful if any standard JRE is 
    rem  installed on the machine.
    rem
    rem  Note: The following code does not use the "loop" feature of the 'for' 
    rem        command! However, the 'for' is required because of the extended 
    rem        variable modifier '%%~$PATH:f', which is used to actually 
    rem        resolve the location of the (hopefully) installed JRE.
    
    if not defined  JavaBin  (
    
        for %%f in ("java.exe") do set JavaBin="%%~$PATH:f"
    )
)


if not exist  %JavaBin%  (
    echo.
    echo.ERROR!  Could not locate a Java Runtime!
    echo.
    echo.  The Java Runtime Environment ^(JRE^) could not be
    echo.  started because the file
    echo.
    echo.      'java.exe'
    echo.
    echo.  could not be found or is not executable.
    echo.
    echo.  Please ensure that an adequate JRE is installed
    echo.  on this computer and can be found by this start
    echo.  script. Then try again..
    echo.
    exit /B 3
)


rem --- java runtime options ---
rem  Use the %GIPPTOOLS_OPTS% environment variable to fine-tune the Java
rem  runtime. See the manual of your JRE for applicable options.
rem
rem  If the environment variable is not set a default of "-Xmx512m' is used.
rem
rem    -Xmx512m .. Limit the maximum memory used by a JRE to roughly half
rem                a gigabyte. (GIPPtools won't need more memory and it is
rem                "good style" to tell the system about it.)
rem
rem  Hint: All Java runtime options starting with '-X...' are non-standard
rem        options specific to a JRE implementation! These options are,
rem        however, portable in the sense that other Java virtual machines
rem        are supposed to simply ignore unknown options and not to throw
rem        an error.

if defined  GIPPTOOLS_OPTS  (

    set JavaOpt="%GIPPTOOLS_OPTS%"

) else (

    set JavaOpt="-Xmx512m"
)


rem  --- run program ---
rem  Finally, do some work and start the requested utility contained in the
rem  Java JAR file. End the script and return the error code set by the
rem  GIPPtools utility.

if /i "%~1"=="--debug"  (
    echo.  DEBUG:   Java runtime environment  JavaBin=%JavaBin%
    echo.  DEBUG:   Java runtime options      JavaOpt=%JavaOpt%
    echo.  DEBUG:   GIPPtools JAR file        JarFile=%JarFile%
    echo.  DEBUG:   GIPPtools utility        ToolName=%ToolName%
    echo.  DEBUG:
    echo.  DEBUG: End of GIPPtools start script. Switching over to Java Runtime now..
    echo.  DEBUG:
)

%JavaBin% %JavaOpt% -jar %JarFile% --run-tool=%ToolName%  %*

exit /B %ERRORLEVEL%


rem  --- fin -------------------------------------------------------------
